==> ipsw-3.1.462.tar.gz: ipsw-3.1.462/www/docs/cli/ipsw/ipsw.md <==
---
id: ipsw
title: ipsw
hide_title: true
hide_table_of_contents: true
sidebar_label: ipsw
description: Download and Parse IPSWs (and SO much more)
---
## ipsw

Download and Parse IPSWs (and SO much more)

### Options

```
      --color           colorize output
      --config string   config file (default is $HOME/.config/ipsw/config.yaml)
  -h, --help            help for ipsw
      --no-color        disable colorize output
  -V, --verbose         verbose output
```

### SEE ALSO

* [ipsw appstore](/docs/cli/ipsw/appstore)	 - Interact with the App Store Connect API
* [ipsw class-dump](/docs/cli/ipsw/class-dump)	 - ObjC class-dump a dylib from a DSC or MachO
* [ipsw device-list](/docs/cli/ipsw/device-list)	 - List all iOS devices
* [ipsw diff](/docs/cli/ipsw/diff)	 - Diff IPSWs
* [ipsw download](/docs/cli/ipsw/download)	 - Download Apple Firmware files (and more)
* [ipsw dtree](/docs/cli/ipsw/dtree)	 - Parse DeviceTree
* [ipsw dyld](/docs/cli/ipsw/dyld)	 - Parse dyld_shared_cache
* [ipsw ent](/docs/cli/ipsw/ent)	 - Search IPSW filesystem DMG or Folder for MachOs with a given entitlement
* [ipsw extract](/docs/cli/ipsw/extract)	 - Extract kernelcache, dyld_shared_cache or DeviceTree from IPSW/OTA
* [ipsw iboot](/docs/cli/ipsw/iboot)	 - Dump firmwares
* [ipsw idev](/docs/cli/ipsw/idev)	 - USB connected device commands
* [ipsw img4](/docs/cli/ipsw/img4)	 - Parse Img4
* [ipsw info](/docs/cli/ipsw/info)	 - Display IPSW/OTA Info
* [ipsw kernel](/docs/cli/ipsw/kernel)	 - Parse kernelcache
* [ipsw macho](/docs/cli/ipsw/macho)	 - Parse MachO
* [ipsw mdevs](/docs/cli/ipsw/mdevs)	 - List all MobileDevices in IPSW
* [ipsw mount](/docs/cli/ipsw/mount)	 - Mount DMG from IPSW
* [ipsw ota](/docs/cli/ipsw/ota)	 - Parse OTAs
* [ipsw plist](/docs/cli/ipsw/plist)	 - Dump plist as JSON
* [ipsw pongo](/docs/cli/ipsw/pongo)	 - PongoOS Terminal
* [ipsw sepfw](/docs/cli/ipsw/sepfw)	 - Dump MachOs
* [ipsw ssh](/docs/cli/ipsw/ssh)	 - SSH into a jailbroken device
* [ipsw swift-dump](/docs/cli/ipsw/swift-dump)	 - 🚧 Swift class-dump a dylib from a DSC or MachO
* [ipsw symbolicate](/docs/cli/ipsw/symbolicate)	 - Symbolicate ARM 64-bit crash logs (similar to Apple's symbolicatecrash)
* [ipsw update](/docs/cli/ipsw/update)	 - Download an ipsw update if one exists
* [ipsw version](/docs/cli/ipsw/version)	 - Print the version number of ipsw
* [ipsw watch](/docs/cli/ipsw/watch)	 - Watch Github Commits

==> ipsw-3.1.470.tar.gz: ipsw-3.1.470/www/docs/cli/ipsw/ipsw.md <==
---
id: ipsw
title: ipsw
hide_title: true
hide_table_of_contents: true
sidebar_label: ipsw
description: Download and Parse IPSWs (and SO much more)
---
## ipsw

Download and Parse IPSWs (and SO much more)

### Options

```
      --color           colorize output
      --config string   config file (default is $HOME/.config/ipsw/config.yaml)
  -h, --help            help for ipsw
      --no-color        disable colorize output
  -V, --verbose         verbose output
```

### SEE ALSO

* [ipsw appstore](/docs/cli/ipsw/appstore)	 - Interact with the App Store Connect API
* [ipsw class-dump](/docs/cli/ipsw/class-dump)	 - ObjC class-dump a dylib from a DSC or MachO
* [ipsw device-list](/docs/cli/ipsw/device-list)	 - List all iOS devices
* [ipsw diff](/docs/cli/ipsw/diff)	 - Diff IPSWs
* [ipsw download](/docs/cli/ipsw/download)	 - Download Apple Firmware files (and more)
* [ipsw dtree](/docs/cli/ipsw/dtree)	 - Parse DeviceTree
* [ipsw dyld](/docs/cli/ipsw/dyld)	 - Parse dyld_shared_cache
* [ipsw ent](/docs/cli/ipsw/ent)	 - Search IPSW filesystem DMG or Folder for MachOs with a given entitlement
* [ipsw extract](/docs/cli/ipsw/extract)	 - Extract kernelcache, dyld_shared_cache or DeviceTree from IPSW/OTA
* [ipsw fw](/docs/cli/ipsw/fw)	 - Firmware commands
* [ipsw idev](/docs/cli/ipsw/idev)	 - USB connected device commands
* [ipsw img4](/docs/cli/ipsw/img4)	 - Parse Img4
* [ipsw info](/docs/cli/ipsw/info)	 - Display IPSW/OTA Info
* [ipsw kernel](/docs/cli/ipsw/kernel)	 - Parse kernelcache
* [ipsw macho](/docs/cli/ipsw/macho)	 - Parse MachO
* [ipsw mdevs](/docs/cli/ipsw/mdevs)	 - List all MobileDevices in IPSW
* [ipsw mount](/docs/cli/ipsw/mount)	 - Mount DMG from IPSW
* [ipsw ota](/docs/cli/ipsw/ota)	 - Parse OTAs
* [ipsw plist](/docs/cli/ipsw/plist)	 - Dump plist as JSON
* [ipsw pongo](/docs/cli/ipsw/pongo)	 - PongoOS Terminal
* [ipsw ssh](/docs/cli/ipsw/ssh)	 - SSH into a jailbroken device
* [ipsw swift-dump](/docs/cli/ipsw/swift-dump)	 - 🚧 Swift class-dump a dylib from a DSC or MachO
* [ipsw symbolicate](/docs/cli/ipsw/symbolicate)	 - Symbolicate ARM 64-bit crash logs (similar to Apple's symbolicatecrash)
* [ipsw update](/docs/cli/ipsw/update)	 - Download an ipsw update if one exists
* [ipsw version](/docs/cli/ipsw/version)	 - Print the version number of ipsw
* [ipsw watch](/docs/cli/ipsw/watch)	 - Watch Github Commits
